Command

Enum Command 

pub enum Command {
    List {
        agent: String,
        last: bool,
        interactive: bool,
        verbose: bool,
        pwd: Option<PathBuf>,
        all_sessions: bool,
    },
    Inspect {
        session: Option<String>,
        last: Option<String>,
        interactive: Option<String>,
        full: bool,
        pwd: Option<PathBuf>,
        all_sessions: bool,
    },
    Handoff {
        first: String,
        second: Option<String>,
        last: Option<String>,
        interactive: Option<String>,
        no_launch: bool,
        pwd: Option<PathBuf>,
        all_sessions: bool,
    },
    Settings {
        action: SettingsAction,
    },
}

Variants



List

Fields

agent: String
last: bool
interactive: bool
verbose: bool
pwd: Option<PathBuf>

Only list sessions whose recorded cwd equals this path. Defaults to the current working directory.

all_sessions: bool

List sessions from every cwd (disables the default cwd filter).



Inspect

Fields

session: Option<String>

Either a session reference like claude:<id>, or a bare agent name (claude / codex) to open the picker for that agent. Omit when using –last or –interactive.

interactive: Option<String>
full: bool
pwd: Option<PathBuf>

Only consider sessions whose recorded cwd equals this path. Defaults to the current working directory. Ignored when an explicit agent:id session reference is provided.

all_sessions: bool

Consider sessions from every cwd (disables the default cwd filter).



Handoff

Fields

first: String

either <source-ref> (e.g. claude:abc) followed by <target>, or just <target> when using --last/--interactive.

second: Option<String>
interactive: Option<String>
no_launch: bool
pwd: Option<PathBuf>

Only consider source sessions whose recorded cwd equals this path. Defaults to the current working directory. Ignored when an explicit agent:id source reference is provided.

all_sessions: bool

Consider source sessions from every cwd (disables the default cwd filter).



Settings

Fields